// Persistence of Vision Ray Tracer Scene Description File
// File: sundail.pov
// Vers: 3
// Desc: Horizontal and vertical sundail 
//       This sundail is NOT suitable for the southern hemisphere,
//       or for use near the poles and equator.
// Date: 15-09-1998
// Auth: ingo
//
// Make an animation of 52 frames. The shadow will describe the figure 8.
// This is the analemma: http://www.skypub.com/catalog/images/p0023.jpg
//
// The motto for this sundail: "By a shadow I explain the heavens"

#include "colors.inc"
#include "textures.inc"

#declare Year= 1998;
#declare Month= 1;
#declare Day= 1+int(clock*365);
#declare Hour= 12;
#declare Minutes= 35;
#declare Lstm= 15;
#declare LONG= 6.9;
#declare LAT= 52.266;
#include "sunpos.inc"

object {Sun}        // is declared in sunpos.inc

global_settings {assumed_gamma 2.2}

camera {
    location  <3.0, 5.0, -5.0>
	look_at   <0.40, 1.8, 0.0>
    angle 40
}  

background {color rgb <0.3,0.2,0.5> }

plane{
    y, 0
    pigment {color Green}
}

    // Builds the horizontal hourlines of the dail.
#declare DailH= cylinder{ <0, 0, 0>, <0, 0, 2>, 0.01 }
#declare HCount= -30;
#while ( HCount<90 )
    #declare RotH = degrees(atan2(tan(radians(HCount))/sin(radians(LAT)),1));
    #declare HourlinesH = union {
        object { 
            cylinder{ <-2, 0, 0>, <0, 0, 0>, 0.01 }
            rotate <0, RotH, 0>
         }
         object { 
            cylinder{ <-2, 0, 0>, <0, 0, 0>, 0.01 }
            rotate <0, 180-RotH, 0>
         }
    }
    #declare DailH= union {
        object { HourlinesH }
        object { DailH }
    }
    #declare HCount=HCount+15;
#end

#declare HGnomon= cylinder { <0, 0, 0>, <0, 0.53, 0>, 0.02
    rotate <90-LAT, 0, 0>
    pigment { color Red }
}

    // Build the vertical hourlines.
#declare DailV= cylinder{ <0, 0, 0>, <0,-2, 0>, 0.01 }
#declare VCount= -30;
#while ( VCount<90 )
    #declare RotV = degrees(atan2(tan(radians(VCount))/cos(radians(LAT)),1));
    #declare HourlinesV = union {
        object { 
            cylinder{ <-2, 0, 0>, <0, 0, 0>, 0.01 }
            rotate <0, 0, RotV>
        }
        object { 
            cylinder{ <-2,0, 0>, <0, 0, 0>, 0.01 }
            rotate <0, 0, 180-RotV>
        }
    }
    #declare DailV = union {
        object { HourlinesV }
        object { DailV }
    }
    #declare VCount= VCount+15;
#end

#declare VGnomon= cylinder { <0, -1.05, 0>, <0, 0, 0>, 0.02
    rotate <90-LAT, 0, 0>
    pigment { color Red }
}

    // Put it all together.
#declare Sundail= union {
    difference {
        box { <-1, 0, 0>, <1, 2.5, 2.5> }
        object { DailH 
            translate <0, 2.5, 0.3>
            pigment { color Gold }
        }
        object { DailV
            translate <0, 2.2, 0>
            pigment { color Gold}
        }
    }
    object { HGnomon
        translate <0, 2.5, 0.3>
    }    
    object { VGnomon
        translate <0, 2.2, 0>
    }    

}

object { Sundail
    pigment{color White}
    finish {diffuse 2}
}


